==> node-clean-css_5.3.1+~5.6.1.orig-cli.tar.gz: clean-css-cli-5.6.1/History.md <==
[5.6.1 / 2022-07-13](https://github.com/clean-css/clean-css-cli/compare/v5.6.0...v5.6.1)
==================

* Bumps clean-css dependency to 5.3.1.

[5.6.0 / 2022-03-31](https://github.com/clean-css/clean-css-cli/compare/v5.5.2...v5.6.0)
==================

* Bumps clean-css dependency to 5.3.0.

[5.5.2 / 2022-01-28](https://github.com/clean-css/clean-css-cli/compare/v5.5.1...v5.5.2)
==================

* Bumps clean-css dependency to 5.2.4.

[5.5.1 / 2022-01-26](https://github.com/clean-css/clean-css-cli/compare/v5.5.0...v5.5.1)
==================

* Bumps clean-css dependency to 5.2.3.

[5.5.0 / 2021-12-08](https://github.com/clean-css/clean-css-cli/compare/5.4...v5.5.0)
==================

* Adds a new `--watch` switch, which makes CLI re-run optimizations when watched file(s) change.

[5.4.2 / 2021-10-21](https://github.com/clean-css/clean-css-cli/compare/v5.4.1...v5.4.2)
==================

* Bumps clean-css dependency to 5.2.2.

[5.4.1 / 2021-09-30](https://github.com/clean-css/clean-css-cli/compare/v5.4.0...v5.4.1)
==================

* Bumps clean-css dependency to 5.2.1.

[5.4.0 / 2021-09-30](https://github.com/clean-css/clean-css-cli/compare/5.3...v5.4.0)
==================

* Bumps clean-css dependency to 5.2.0.

[5.3.3 / 2021-08-05](https://github.com/clean-css/clean-css-cli/compare/v5.3.2...v5.3.3)
==================

* Bumps clean-css dependency to 5.1.5.

[5.3.2 / 2021-07-29](https://github.com/clean-css/clean-css-cli/compare/v5.3.1...v5.3.2)
==================

* Bumps clean-css dependency to 5.1.4.

[5.3.1 / 2021-07-29](https://github.com/clean-css/clean-css-cli/compare/v5.3.0...v5.3.1)
==================

* Bumps clean-css dependency to 5.1.3.

[5.3.0 / 2021-04-28](https://github.com/clean-css/clean-css-cli/compare/5.2...v5.3.0)
==================

* Fixed issue [#61](https://github.com/clean-css/clean-css-cli/issues/61) - source maps, rebasing, and batch processing.
* Fixed issue [#65](https://github.com/clean-css/clean-css-cli/issues/65) - batch processing with output path.

[5.2.2 / 2021-03-19](https://github.com/clean-css/clean-css-cli/compare/v5.2.1...v5.2.2)
==================

* Bumps clean-css dependency to 5.1.2.

[5.2.1 / 2021-03-03](https://github.com/clean-css/clean-css-cli/compare/v5.2.0...v5.2.1)
==================

* Bumps clean-css dependency to 5.1.1.

[5.2.0 / 2021-02-18](https://github.com/clean-css/clean-css-cli/compare/5.1...v5.2.0)
==================

* Bumps clean-css dependency to 5.1.0.

[5.1.0 / 2021-02-12](https://github.com/clean-css/clean-css-cli/compare/5.0...v5.1.0)
==================

* Fixed issue [#51](https://github.com/clean-css/clean-css-cli/issues/51) - excluding files via glob negated pattern.

[5.0.1 / 2021-02-11](https://github.com/clean-css/clean-css-cli/compare/v5.0.0...v5.0.1)
==================

* Fixed issue [#54](https://github.com/clean-css/clean-css-cli/issues/54) - rebasing is still on if output option is used.

[5.0.0 / 2021-02-10](https://github.com/clean-css/clean-css-cli/compare/4.3...v5.0.0)
==================

* Adds `--batch-suffix` option to specify what gets appended to output filename in batch mode.
* Bumps clean-css dependency to 5.0.
* Bumps commander dependency to 7.0.
* Fixed issue [#18](https://github.com/clean-css/clean-css-cli/issues/18) - allows batch processing of input files.
* Fixed issue [#36](https://github.com/clean-css/clean-css-cli/issues/36) - automatically creates missing output directories.

[4.3.0 / 2019-04-06](https://github.com/clean-css/clean-css-cli/compare/4.2...v4.3.0)
==================

* Bumps clean-css dependency to 4.2.1.
* Fixed issue [#21](https://github.com/clean-css/clean-css-cli/issues/21) - sanity check for printing out help.
* Fixed issue [#27](https://github.com/clean-css/clean-css-cli/issues/27) - way to provide input source map.

[4.2.0 / 2018-08-02](https://github.com/clean-css/clean-css-cli/compare/4.1...v4.2.0)
==================

* Bumps clean-css dependency to 4.2.0.

[4.1.11 / 2018-03-02](https://github.com/clean-css/clean-css-cli/compare/v4.1.10...v4.1.11)
==================

* Fixed issue [#17](https://github.com/clean-css/clean-css-cli/issues/17) - empty `--inline` switch.

[4.1.10 / 2017-09-19](https://github.com/clean-css/clean-css-cli/compare/v4.1.9...v4.1.10)
==================

* Bumps clean-css dependency to 4.1.9.

[4.1.9 / 2017-09-03](https://github.com/clean-css/clean-css-cli/compare/v4.1.8...v4.1.9)
==================

* Bumps clean-css dependency to 4.1.8.

[4.1.8 / 2017-09-03](https://github.com/clean-css/clean-css-cli/compare/v4.1.7...v4.1.8)
==================

* Bumps clean-css dependency to 4.1.7.

[4.1.7 / 2017-09-03](https://github.com/clean-css/clean-css-cli/compare/v4.1.6...v4.1.7)
==================

* Bumps clean-css dependency to 4.1.6.

[4.1.6 / 2017-06-29](https://github.com/clean-css/clean-css-cli/compare/v4.1.5...v4.1.6)
==================

* Bumps clean-css dependency to 4.1.5.

[4.1.5 / 2017-06-14](https://github.com/clean-css/clean-css-cli/compare/v4.1.4...v4.1.5)
==================

* Bumps clean-css dependency to 4.1.4.

[4.1.4 / 2017-06-09](https://github.com/clean-css/clean-css-cli/compare/v4.1.3...v4.1.4)
==================

* Fixed issue [#10](https://github.com/clean-css/clean-css-cli/issues/10) - IE/Edge source maps.

[4.1.3 / 2017-05-18](https://github.com/clean-css/clean-css-cli/compare/v4.1.2...v4.1.3)
==================

* Bumps clean-css dependency to 4.1.3.

[4.1.2 / 2017-05-10](https://github.com/clean-css/clean-css-cli/compare/v4.1.1...v4.1.2)
==================

* Bumps clean-css dependency to 4.1.2.

[4.1.1 / 2017-05-10](https://github.com/clean-css/clean-css-cli/compare/v4.1.0...v4.1.1)
==================

* Bumps clean-css dependency to 4.1.1.

[4.1.0 / 2017-05-08](https://github.com/clean-css/clean-css-cli/compare/4.0...v4.1.0)
==================

* Bumps clean-css dependency to 4.1.x.
* Fixed issue [#1](https://github.com/clean-css/clean-css-cli/issues/1) - option to remove inlined files.
* Fixed issue [#2](https://github.com/clean-css/clean-css-cli/issues/2) - glob matching source paths.
* Fixed issue [#5](https://github.com/clean-css/clean-css-cli/issues/5) - non-boolean compatibility options.
* Fixed issue [#7](https://github.com/clean-css/clean-css-cli/issues/7) - using CLI as a module.

[4.0.12 / 2017-04-12](https://github.com/clean-css/clean-css-cli/compare/v4.0.11...v4.0.12)
==================

* Bumps clean-css dependency to 4.0.12.

[4.0.11 / 2017-04-11](https://github.com/clean-css/clean-css-cli/compare/v4.0.10...v4.0.11)
==================

* Bumps clean-css dependency to 4.0.11.

[4.0.10 / 2017-03-22](https://github.com/clean-css/clean-css-cli/compare/v4.0.9...v4.0.10)
==================

* Bumps clean-css dependency to 4.0.10.

[4.0.9 / 2017-03-15](https://github.com/clean-css/clean-css-cli/compare/v4.0.8...v4.0.9)
==================

* Bumps clean-css dependency to 4.0.9.

[4.0.8 / 2017-02-22](https://github.com/clean-css/clean-css-cli/compare/v4.0.7...v4.0.8)
==================

* Bumps clean-css dependency to 4.0.8.

[4.0.7 / 2017-02-14](https://github.com/clean-css/clean-css-cli/compare/v4.0.6...v4.0.7)
==================

* Bumps clean-css dependency to 4.0.7.

[4.0.6 / 2017-02-10](https://github.com/clean-css/clean-css-cli/compare/v4.0.5...v4.0.6)
==================

* Bumps clean-css dependency to 4.0.6.

[4.0.5 / 2017-02-07](https://github.com/clean-css/clean-css-cli/compare/v4.0.4...v4.0.5)
==================

* Bumps clean-css dependency to 4.0.5.

[4.0.4 / 2017-02-07](https://github.com/clean-css/clean-css-cli/compare/v4.0.3...v4.0.4)
==================

* Bumps clean-css dependency to 4.0.4.

[4.0.3 / 2017-02-07](https://github.com/clean-css/clean-css-cli/compare/v4.0.2...v4.0.3)
==================

* Bumps clean-css dependency to 4.0.3.

[4.0.2 / 2017-02-07](https://github.com/clean-css/clean-css-cli/compare/v4.0.1...v4.0.2)
==================

* Bumps clean-css dependency to 4.0.2.

[4.0.1 / 2017-02-07](https://github.com/clean-css/clean-css-cli/compare/v4.0.0...v4.0.1)
==================

* Bumps clean-css dependency to 4.0.1.

4.0.0 / 2017-01-23
==================

* Initial release of separate clean-css-cli.
* See [clean-css release notes](https://github.com/clean-css/clean-css/blob/master/History.md#400--2017-01-23) for a full list of changes.

==> node-clean-css_5.3.3+~5.6.3.orig-cli.tar.gz: clean-css-cli-5.6.3/History.md <==
[5.6.3 / 2023-11-30](https://github.com/clean-css/clean-css-cli/compare/v5.6.2...v5.6.3)
==================

* Bumps clean-css dependency to 5.3.3

[5.6.2 / 2023-01-19](https://github.com/clean-css/clean-css-cli/compare/v5.6.1...v5.6.2)
==================

* Bumps clean-css dependency to 5.3.2

[5.6.1 / 2022-07-13](https://github.com/clean-css/clean-css-cli/compare/v5.6.0...v5.6.1)
==================

* Bumps clean-css dependency to 5.3.1.

[5.6.0 / 2022-03-31](https://github.com/clean-css/clean-css-cli/compare/v5.5.2...v5.6.0)
==================

* Bumps clean-css dependency to 5.3.0.

[5.5.2 / 2022-01-28](https://github.com/clean-css/clean-css-cli/compare/v5.5.1...v5.5.2)
==================

* Bumps clean-css dependency to 5.2.4.

[5.5.1 / 2022-01-26](https://github.com/clean-css/clean-css-cli/compare/v5.5.0...v5.5.1)
==================

* Bumps clean-css dependency to 5.2.3.

[5.5.0 / 2021-12-08](https://github.com/clean-css/clean-css-cli/compare/5.4...v5.5.0)
==================

* Adds a new `--watch` switch, which makes CLI re-run optimizations when watched file(s) change.

[5.4.2 / 2021-10-21](https://github.com/clean-css/clean-css-cli/compare/v5.4.1...v5.4.2)
==================

* Bumps clean-css dependency to 5.2.2.

[5.4.1 / 2021-09-30](https://github.com/clean-css/clean-css-cli/compare/v5.4.0...v5.4.1)
==================

* Bumps clean-css dependency to 5.2.1.

[5.4.0 / 2021-09-30](https://github.com/clean-css/clean-css-cli/compare/5.3...v5.4.0)
==================

* Bumps clean-css dependency to 5.2.0.

[5.3.3 / 2021-08-05](https://github.com/clean-css/clean-css-cli/compare/v5.3.2...v5.3.3)
==================

* Bumps clean-css dependency to 5.1.5.

[5.3.2 / 2021-07-29](https://github.com/clean-css/clean-css-cli/compare/v5.3.1...v5.3.2)
==================

* Bumps clean-css dependency to 5.1.4.

[5.3.1 / 2021-07-29](https://github.com/clean-css/clean-css-cli/compare/v5.3.0...v5.3.1)
==================

* Bumps clean-css dependency to 5.1.3.

[5.3.0 / 2021-04-28](https://github.com/clean-css/clean-css-cli/compare/5.2...v5.3.0)
==================

* Fixed issue [#61](https://github.com/clean-css/clean-css-cli/issues/61) - source maps, rebasing, and batch processing.
* Fixed issue [#65](https://github.com/clean-css/clean-css-cli/issues/65) - batch processing with output path.

[5.2.2 / 2021-03-19](https://github.com/clean-css/clean-css-cli/compare/v5.2.1...v5.2.2)
==================

* Bumps clean-css dependency to 5.1.2.

[5.2.1 / 2021-03-03](https://github.com/clean-css/clean-css-cli/compare/v5.2.0...v5.2.1)
==================

* Bumps clean-css dependency to 5.1.1.

[5.2.0 / 2021-02-18](https://github.com/clean-css/clean-css-cli/compare/5.1...v5.2.0)
==================

* Bumps clean-css dependency to 5.1.0.

[5.1.0 / 2021-02-12](https://github.com/clean-css/clean-css-cli/compare/5.0...v5.1.0)
==================

* Fixed issue [#51](https://github.com/clean-css/clean-css-cli/issues/51) - excluding files via glob negated pattern.

[5.0.1 / 2021-02-11](https://github.com/clean-css/clean-css-cli/compare/v5.0.0...v5.0.1)
==================

* Fixed issue [#54](https://github.com/clean-css/clean-css-cli/issues/54) - rebasing is still on if output option is used.

[5.0.0 / 2021-02-10](https://github.com/clean-css/clean-css-cli/compare/4.3...v5.0.0)
==================

* Adds `--batch-suffix` option to specify what gets appended to output filename in batch mode.
* Bumps clean-css dependency to 5.0.
* Bumps commander dependency to 7.0.
* Fixed issue [#18](https://github.com/clean-css/clean-css-cli/issues/18) - allows batch processing of input files.
* Fixed issue [#36](https://github.com/clean-css/clean-css-cli/issues/36) - automatically creates missing output directories.

[4.3.0 / 2019-04-06](https://github.com/clean-css/clean-css-cli/compare/4.2...v4.3.0)
==================

* Bumps clean-css dependency to 4.2.1.
* Fixed issue [#21](https://github.com/clean-css/clean-css-cli/issues/21) - sanity check for printing out help.
* Fixed issue [#27](https://github.com/clean-css/clean-css-cli/issues/27) - way to provide input source map.

[4.2.0 / 2018-08-02](https://github.com/clean-css/clean-css-cli/compare/4.1...v4.2.0)
==================

* Bumps clean-css dependency to 4.2.0.

[4.1.11 / 2018-03-02](https://github.com/clean-css/clean-css-cli/compare/v4.1.10...v4.1.11)
==================

* Fixed issue [#17](https://github.com/clean-css/clean-css-cli/issues/17) - empty `--inline` switch.

[4.1.10 / 2017-09-19](https://github.com/clean-css/clean-css-cli/compare/v4.1.9...v4.1.10)
==================

* Bumps clean-css dependency to 4.1.9.

[4.1.9 / 2017-09-03](https://github.com/clean-css/clean-css-cli/compare/v4.1.8...v4.1.9)
==================

* Bumps clean-css dependency to 4.1.8.

[4.1.8 / 2017-09-03](https://github.com/clean-css/clean-css-cli/compare/v4.1.7...v4.1.8)
==================

* Bumps clean-css dependency to 4.1.7.

[4.1.7 / 2017-09-03](https://github.com/clean-css/clean-css-cli/compare/v4.1.6...v4.1.7)
==================

* Bumps clean-css dependency to 4.1.6.

[4.1.6 / 2017-06-29](https://github.com/clean-css/clean-css-cli/compare/v4.1.5...v4.1.6)
==================

* Bumps clean-css dependency to 4.1.5.

[4.1.5 / 2017-06-14](https://github.com/clean-css/clean-css-cli/compare/v4.1.4...v4.1.5)
==================

* Bumps clean-css dependency to 4.1.4.

[4.1.4 / 2017-06-09](https://github.com/clean-css/clean-css-cli/compare/v4.1.3...v4.1.4)
==================

* Fixed issue [#10](https://github.com/clean-css/clean-css-cli/issues/10) - IE/Edge source maps.

[4.1.3 / 2017-05-18](https://github.com/clean-css/clean-css-cli/compare/v4.1.2...v4.1.3)
==================

* Bumps clean-css dependency to 4.1.3.

[4.1.2 / 2017-05-10](https://github.com/clean-css/clean-css-cli/compare/v4.1.1...v4.1.2)
==================

* Bumps clean-css dependency to 4.1.2.

[4.1.1 / 2017-05-10](https://github.com/clean-css/clean-css-cli/compare/v4.1.0...v4.1.1)
==================

* Bumps clean-css dependency to 4.1.1.

[4.1.0 / 2017-05-08](https://github.com/clean-css/clean-css-cli/compare/4.0...v4.1.0)
==================

* Bumps clean-css dependency to 4.1.x.
* Fixed issue [#1](https://github.com/clean-css/clean-css-cli/issues/1) - option to remove inlined files.
* Fixed issue [#2](https://github.com/clean-css/clean-css-cli/issues/2) - glob matching source paths.
* Fixed issue [#5](https://github.com/clean-css/clean-css-cli/issues/5) - non-boolean compatibility options.
* Fixed issue [#7](https://github.com/clean-css/clean-css-cli/issues/7) - using CLI as a module.

[4.0.12 / 2017-04-12](https://github.com/clean-css/clean-css-cli/compare/v4.0.11...v4.0.12)
==================

* Bumps clean-css dependency to 4.0.12.

[4.0.11 / 2017-04-11](https://github.com/clean-css/clean-css-cli/compare/v4.0.10...v4.0.11)
==================

* Bumps clean-css dependency to 4.0.11.

[4.0.10 / 2017-03-22](https://github.com/clean-css/clean-css-cli/compare/v4.0.9...v4.0.10)
==================

* Bumps clean-css dependency to 4.0.10.

[4.0.9 / 2017-03-15](https://github.com/clean-css/clean-css-cli/compare/v4.0.8...v4.0.9)
==================

* Bumps clean-css dependency to 4.0.9.

[4.0.8 / 2017-02-22](https://github.com/clean-css/clean-css-cli/compare/v4.0.7...v4.0.8)
==================

* Bumps clean-css dependency to 4.0.8.

[4.0.7 / 2017-02-14](https://github.com/clean-css/clean-css-cli/compare/v4.0.6...v4.0.7)
==================

* Bumps clean-css dependency to 4.0.7.

[4.0.6 / 2017-02-10](https://github.com/clean-css/clean-css-cli/compare/v4.0.5...v4.0.6)
==================

* Bumps clean-css dependency to 4.0.6.

[4.0.5 / 2017-02-07](https://github.com/clean-css/clean-css-cli/compare/v4.0.4...v4.0.5)
==================

* Bumps clean-css dependency to 4.0.5.

[4.0.4 / 2017-02-07](https://github.com/clean-css/clean-css-cli/compare/v4.0.3...v4.0.4)
==================

* Bumps clean-css dependency to 4.0.4.

[4.0.3 / 2017-02-07](https://github.com/clean-css/clean-css-cli/compare/v4.0.2...v4.0.3)
==================

* Bumps clean-css dependency to 4.0.3.

[4.0.2 / 2017-02-07](https://github.com/clean-css/clean-css-cli/compare/v4.0.1...v4.0.2)
==================

* Bumps clean-css dependency to 4.0.2.

[4.0.1 / 2017-02-07](https://github.com/clean-css/clean-css-cli/compare/v4.0.0...v4.0.1)
==================

* Bumps clean-css dependency to 4.0.1.

4.0.0 / 2017-01-23
==================

* Initial release of separate clean-css-cli.
* See [clean-css release notes](https://github.com/clean-css/clean-css/blob/master/History.md#400--2017-01-23) for a full list of changes.
